# HostConfigCategory

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**count_vm_available** | **int** |  | 
**cpu_model** | **str** |  | 
**data_center_id** | **str** |  | 
**gpu_model** | **str** |  | 
**gpu_price_hr** | [**Decimal**](Decimal.md) |  | 
**id** | **str** |  | 
**ipv4_price_hr** | [**Decimal**](Decimal.md) |  | 
**machine_type** | **str** |  | 
**memory_gib_price_hr** | [**Decimal**](Decimal.md) |  | 
**renewable_energy** | **bool** |  | 
**storage_gib_price_hr** | [**Decimal**](Decimal.md) |  | 
**total_gpu_price_hr** | [**Decimal**](Decimal.md) |  | 
**total_memory_price_hr** | [**Decimal**](Decimal.md) |  | 
**total_price_hr** | [**Decimal**](Decimal.md) |  | 
**total_storage_price_hr** | [**Decimal**](Decimal.md) |  | 
**total_vcpu_price_hr** | [**Decimal**](Decimal.md) |  | 
**vcpu_price_hr** | [**Decimal**](Decimal.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


